﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

using Windows.Storage;
using Windows.Storage.Pickers;
using C1.C1Zip;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace ZipEncryptionSample
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private C1ZipFile _zip;
        private List<StorageFile> _files;

        public MainPage()
        {
            this.InitializeComponent();

            // create a zip file to work with
            _zip = new C1ZipFile();

            // create list to store files prior to zipping
            _files = new List<StorageFile>();
        }

        // launches file picker to select files to be zipped
        private async void btnAddFile_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                var picker = new Windows.Storage.Pickers.FileOpenPicker();
                picker.ViewMode = Windows.Storage.Pickers.PickerViewMode.List;
                picker.SuggestedStartLocation = Windows.Storage.Pickers.PickerLocationId.DocumentsLibrary;
                picker.FileTypeFilter.Add("*");

                var files = await picker.PickMultipleFilesAsync();
                if (files != null)
                {
                    foreach (var f in files)
                    {
                        _files.Add(f);
                    }
                }
            }
            catch
            {
                // snapped?
            }
            RefreshView();
        }

        // removes selected file(s) from the list
        private void btnRemove_Click(object sender, RoutedEventArgs e)
        {
            foreach (StorageFile file in c1FlexGrid1.SelectedItems)
            {
                _files.Remove(file);
            }
            RefreshView();
        }

        // compresses all files into selected zip file with option for encryption
        private async void btnCompressEncrypt_Click(object sender, RoutedEventArgs e)
        {
            try
            {
                FileSavePicker savePicker = new FileSavePicker();
                savePicker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
                savePicker.FileTypeChoices.Add("Zip Archive", new List<string>() { ".zip" });
                savePicker.DefaultFileExtension = ".zip";

                StorageFile file = await savePicker.PickSaveFileAsync();
                if (file != null)
                {
                    // create zip from file picker stream
                    _zip.Create(await file.OpenStreamForWriteAsync());

                    // set password
                    if ((bool)chkEncrypt.IsChecked)
                    {
                        _zip.Password = txtPassword.Text;
                    }

                    // add files to zip
                    foreach (StorageFile f in _files)
                    {
                        await _zip.Entries.AddAsync(f);
                    }

                    // close zip file
                    _zip.CloseBatch();
                }
            }
            catch
            {
                // snapped?
            }
        }

        // refresh view when collection is modified
        void RefreshView()
        {
            var sel = c1FlexGrid1.SelectedItem;
            c1FlexGrid1.ItemsSource = null;
            c1FlexGrid1.ItemsSource = _files;
            c1FlexGrid1.SelectedItem = sel;
        }

        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
        }
    }
}
